@@ -215,7 +215,6 @@ flames_add_bt_info(
 
 
   double fib_pos_tmp_val=0;
-  double fib_pos_sel_val=0;
   double fib_pos[N_FIBRES_MAX];
   double fib_pos_val[N_FIBRES_MAX];
 
@@ -419,6 +418,7 @@ flames_add_bt_info(
 	printf("fib_pos_tmp_val=%g\n",fib_pos_tmp_val);
 	printf("fib_pos_check_val=%g\n",fib_pos[fib_id]);
       */        
+      double fib_pos_sel_val=0;
       if (fabs(fib_pos_tmp_val-fib_pos[fib_id]) <= precision){
 	fib_pos_sel_val=fib_pos_tmp_val;
 	raw_sel=i;
@@ -428,11 +428,6 @@ flames_add_bt_info(
       } 
     }
   }
-  /*
-    printf("raw_sel=%d\n",raw_sel);
-    printf("fib_pos=%g\n",fib_pos_sel_val);
-  */
- 
 
   TCERDR(tab_in_bt_id,raw_sel,col_fib_pos,  &info_fib_pos,   &null);
   TCERDI(tab_in_bt_id,raw_sel,col_fib_msk,  &info_fib_msk,   &null);
